/********************************************************************/
/* COPYRIGHTS:                                                      */
/*                                                                  */
/*   This module contains code made available by IBM Corporation on */
/* an AS IS basis.  Any one receiving the module is  considered  to */
/* be  licensed under IBM copyrights to use the IBM-provided source */
/* code in any way he or  she  deems  fit,  including  copying  it, */
/* compiling  it,  modifying  it,  and  redistributing  it, with or */
/* without modifications.  No license  under  any  IBM  patents  or */
/* patent  applications  is  to  be  implied  from  this  copyright */
/* license.                                                         */
/*                                                                  */
/*   A user of the module should understand that IBM cannot provide */
/* technical support for the module and will not be responsible for */
/* any consequences of use of the program.                          */
/*                                                                  */
/*   Any notice,  including this one, are not to  be  removed  from */
/* the module with out the prior written consent of IBM.            */
/*                                                                  */
/********************************************************************/

/***********************************************************************************************
/*
/*   ftppf          version 1.0            2005/04/26                    Michael J. Swenson
/*
/*   This ftp program makes use of the IBM Toolbox for Java AS400FTP class and demonstrates
/*   how to work with some of the shortcommings in this class.  Especially the inability to 
/*   perform CCSID conversion.
/* 
/*   Usage: ftppf userid password physicalFilename ifsFilename
/*   The filenames use IFS naming convention for example:
/*      ftppf myid mypassword /qsys.lib/qiws.lib/qcustcdt.file/custcdt.mbr /mydir/myfile.txt
/*
/**********************************************************************************************/
		
import com.ibm.as400.access.*;
import java.io.*;

public class ftppf {

	public ftppf() { }
	public static void main(String[] args) 
	{
		int MAXREADSIZE = 1024;		// The amount of data we read, convert, write at one time
		int STMFCODEPAGE = 1252;	// CCSID for the stream file
		int fileOffset = 0;			// offset into the file we are reading
		int byteCount = 0;
		String data = "";
		byte rawBytes[] = new byte[MAXREADSIZE];
		boolean complete = false;
		String LOCALSYSTEMNAME = "RCHASCLC";

		// Parse the input parameters
		if (args.length < 4)
		{
			System.out.println ("Usage: ftppf userid password physicalFilename ifsFilename");
			System.out.println ("The filenames use IFS naming convention for example:");
			System.out.println ("ftppf myid mypassword /qsys.lib/qiws.lib/qcustcdt.file/custcdt.mbr /mydir/myfile.txt");
			System.out.println ();
			System.out.println ("The member name may be omitted if the file only has a single member.");
			System.exit(20);
		}
		String userID = args[0];
		String password = args[1];
		String physicalFile = args[2];
		String ifsFile = args[3];

		AS400FTP client = new AS400FTP();
		try
		{	
			AS400 system = new AS400(LOCALSYSTEMNAME, userID, password);
			client.setSystem(system);
			client.connect();
			IFSFile thePF = new IFSFile(system, physicalFile);
			if (!thePF.exists())
			{
				System.out.println("The file " + thePF + " does not exist.");
				System.exit(20);
			}
//			System.out.println(client.issueCommand("site namefmt 1"));
			InputStream inStream = client.get(physicalFile);
			if (inStream == null)
			{
				System.out.println("Get failed to open input file.");
				System.exit(20);
			}

			// create a character converter to convert from job ccsid to ANSI
			CharConverter converter = new CharConverter(STMFCODEPAGE);

			// Create the stream file with an ANSI CCSID: 1252.
			IFSFile file = new IFSFile(system, ifsFile);
			file.createNewFile();
			file.setCCSID(STMFCODEPAGE);
			IFSFileWriter fileWriter = new IFSFileWriter(file, STMFCODEPAGE);

			while (!complete) 
			{
				// Read the input file in MAXREADSIZE chunks at a time.
				byteCount = inStream.read(rawBytes, 0, MAXREADSIZE);
				if (byteCount < MAXREADSIZE)
					complete = true;
				fileOffset += byteCount;
//				System.out.println("Read " + byteCount + " bytes of data. Total read: " + fileOffset);
				data = converter.byteArrayToString(rawBytes, 0, byteCount);
//				System.out.println("Data : \n" + data + "\n");
				fileWriter.write(data);
				fileWriter.flush();
			}

			fileWriter.flush();
			fileWriter.close();
			System.out.println("FTPPF completed successfully.");
			System.out.println(fileOffset + " bytes transfered from " + physicalFile + " to " + ifsFile);
			client.disconnect();
		}
		catch (IOException ioe)
		{
			System.out.println(ioe.getMessage());
		}
		catch (Exception e)
		{
			System.out.println(e.getMessage());
		}
	}
}